#include "..\..\script_component.hpp"
/***************************************************************************
* Author: Lambda.Tiger
*
* Description:
* This function handles all display upates for the consoles
*
* Arguments:
*  _force - Force draw the event
*
* Return:
* none
*
* Example:
* [] call lmd_fnc_drawScreen;
* [true] call lmd_fnc_drawScreen;
******************************************************************************/
params [["_force", false]];
private _removeKeys = [];
{
    _y params ["_console", "_endTime", "_runTime", "_lastTimeLeft", "_lastPercent"];
    private _timeLeft = _endTime - time;
    private _floatDone = 1 - _timeLeft / _runTime;
    private _percent = floor (100 * _floatDone);
    if (_timeLeft < 0) then {
        _removeKeys pushBack _x;
        [_console, _endTime, _runTime, true] call FUNC(initCountdown);
        continue;
    };
    _timeLeft = round _timeLeft;
    if (!_force && (ace_player distance _console > 250 ||
        {_lastTimeLeft == _timeLeft &&
        _lastPercent == _percent})) then {continue};
    _y set [3, _timeLeft];
    _y set [4, _percent];
    private _minutesLeft = str (floor (_timeLeft/60));
    private _secondsLeft = _timeLeft mod 60;
    _secondsLeft = if (_secondsLeft < 10) then {
        "0" + str _secondsLeft
    } else {
        str _secondsLeft
    };
    // Text
    private _display = findDisplay (_x + "Count");
    if (isNull _display) then {
#if LMD_DEBUG_MODE >= 2
        diag_log formatText ["[LMD][DEBUG] Failed to find Count UI for %1", _console];
#endif
        if (_timeLeft mod 6 == 2 && _lastTimeLeft != _timeLeft) then {
#if LMD_DEBUG_MODE >= 1
            diag_log formatText ["[LMD][DEBUG] Trying to genererate new count screen for %1 @ %2s left | %3", _console, _timeLeft, _percent];
#endif
            _console setObjectTexture ["Screen_1", format ["#(rgb,512,512,1)uiEx(display:RscCountDown,uniqueName:%1Count,texType:co)", _console]];
        };
    } else {
        private _text = _display displayCtrl IDC_DISPLAY_COUNT_TEXT;
        _text ctrlSetStructuredText (parseText format ["ETA:<br/>%1:%2", _minutesLeft, _secondsLeft]);
        displayUpdate _display;
    };
    // Loading bar
    _display = findDisplay (_x + "Bar");
    if (isNull _display) then {
#if LMD_DEBUG_MODE >= 2
        diag_log formatText ["[LMD][DEBUG] Failed to find Bar UI for %1", _console];
#endif
        if (_timeLeft mod 6 == 5 && _lastTimeLeft != _timeLeft) then {
#if LMD_DEBUG_MODE >= 1
            diag_log formatText ["[LMD][DEBUG] Trying to genererate new bar screen for %1 @ %2 s left | %3", _console, _timeLeft, _percent];
#endif
            _console setObjectTexture ["Screen_3", format ["#(rgb,512,512,1)uiEx(display:RscLoadingBar,uniqueName:%1Bar,texType:co)", _console]];
        };
    } else {
        private _text = _display displayCtrl IDC_DISPLAY_LOAD_TEXT;
        private _bar = _display displayCtrl IDC_DISPLAY_LOAD_BAR;
        _bar progressSetPosition _floatDone;
        _text ctrlSetStructuredText (parseText format ["PERCENT:<br/>%1%%", _percent]);
        displayUpdate _display;
    };
} forEach GVAR(countdownDisplays);
{
    GVAR(countdownDisplays) deleteAt _x;
} forEach _removeKeys;
if (GVAR(countdownDisplays) isEqualTo createHashMap) then {
    removeMissionEventHandler [_thisEvent, _thisEventHandler];
    GVAR(computerDisplayEH) = -1;
};
