#include "..\..\script_component.hpp"
/***************************************************************************
* Author: Lambda.Tiger
*
* Description:
* This function handles the countdown event - formerly CBA event
*
* Arguments:
*  _computer - The three screened computer to draw on
*  _endTime - End time of the of the countdown (CBA_missionTime relative)
*  _countdownTime - Time to cound down in seconds
*  _finished - Whether the screen event was finishing the display or initializng
*
* Return:
* none
*
* Example:
* [console, CBA_missionTime + 30, 30, false] call lmd_fnc_initCountdown;
* [console, CBA_missionTime + 30, 0, true] call lmd_fnc_initCountdown;
******************************************************************************/
diag_log format ["PARAMS:%1",_this];
params ["_computer", "_endTime", "_countdownTime", ["_finished", false]];
if (isNull _computer) exitWith {};

if (_finished) exitWith {
    _computer setObjectTexture ["Screen_1", "#(rgb,512,512,3)text(1,1,""RobotoCondensedLight"",0.3,""#000000"",""#00CC00"",""ETA:\nFINISHED"")"];
    _computer removeAction (_computer getVariable [QGVAR(shutDownAction), -1]);
    private _display = findDisplay (format ["%1Bar", _computer]);
    if (isNull _display) then {
        _computer setObjectTexture ["Screen_3", "#(rgb,512,512,3)text(1,1,""RobotoCondensedLight"",0.2,""#000000"",""#00CC00"",""PERCENT:\n100%"")"];
    } else {
        private _text = _display displayCtrl IDC_DISPLAY_LOAD_TEXT;
        private _bar = _display displayCtrl IDC_DISPLAY_LOAD_BAR;
        private _back = _display displayCtrl IDC_DISPLAY_LOAD_BACK;
        _text ctrlSetTextColor [0,0.8,0.1,1];
        _text ctrlSetStructuredText (parseText "PERCENT:<br/>100%");
        _bar ctrlSetTextColor [0,0.8,0.1,1];
        _bar progressSetPosition 1;
        displayUpdate _display;
    };
    _computer setObjectTexture ["Screen_2", "#(rgb,512,512,3)text(1,1,""RobotoCondensedLight"",0.2,""#000000"",""#00CC00"",""COUNTDOWN\nCOMPLETED"")"];
    GVAR(countdownDisplays) deleteAt str _computer;
};

if (GVAR(computerDisplayEH) < 0) then {
    GVAR(computerDisplayEH) = addMissionEventHandler ["Draw2D",{
        [] call FUNC(drawScreens);
    }];
};

_computer setObjectTexture ["Screen_1", format ["#(rgb,512,512,1)uiEx(display:RscCountDown,uniqueName:%1Count,texType:co)", _computer]];
_computer setObjectTexture ["Screen_2", "#(rgb,512,512,3)text(1,1,""RobotoCondensedLight"",0.2,""#000000"",""#ffffff"",""Running\ncountdown"")"];
_computer setObjectTexture ["Screen_3", format ["#(rgb,512,512,1)uiEx(display:RscLoadingBar,uniqueName:%1Bar,texType:co)", _computer]];
GVAR(countdownDisplays) set [str _computer, [_computer, _endTime, _countdownTime, -1, -1]];

#if LMD_DEBUG_MODE >= 1
diag_log formatText ["[LMD][DEBUG] Created displays on %1 @ %2 | %3 | %4", _computer, time, format ["#(rgb,512,512,1)uiEx(display:RscCountDown,uniqueName:%1Count,texType:co)", _computer], format ["#(rgb,512,512,1)uiEx(display:RscLoadingBar,uniqueName:%1Bar,texType:co)", _computer]];
#endif

_computer removeAction (_computer getVariable [QGVAR(beginCountdownActionID), -1]);
